summaryrefslogtreecommitdiff
path: root/include/f_op
diff options
context:
space:
mode:
authorLagoLunatic <LagoLunatic@users.noreply.github.com>2025-12-23 18:53:10 -0500
committerGitHub <noreply@github.com>2025-12-23 15:53:10 -0800
commit877889c5105e59ee3aa4e57e53d3b0c5ffcfca77 (patch)
tree154eddaea39971210e088cb828f80d38b998f998 /include/f_op
parent6ef13c620a46aed5fea525699a4832a1ad6e4d1f (diff)
Clean up code, remove fakematches, add UNUSED, enable warnings (#2992)
* Remove NDEBUG_DEFINED fakematch, clean up getName temps * Fix ifdef * Fix bad JSystem pch ifdef breaking decomp.me * Remove Acch Chk fakematches * Private Acch fields * Fix some clangd errors in headers * Add UNUSED macro for matching debug parameters * Enable clangd unused-parameter warning * Remove extern from initializers Probably added by dol2asm? * Fix process profile definitions * Remove leftover dol2asm address comments * Remove some unnecessary double casts * Enable some more clangd warnings * Fix missing usages of fopAcM_ct * Fix wrong enum usage * Fix more fakematches
Diffstat (limited to 'include/f_op')
-rw-r--r--include/f_op/f_op_actor_mng.h2
-rw-r--r--include/f_op/f_op_scene.h9
2 files changed, 8 insertions, 3 deletions
diff --git a/include/f_op/f_op_actor_mng.h b/include/f_op/f_op_actor_mng.h
index b5a11a6beb..dbf01d374d 100644
--- a/include/f_op/f_op_actor_mng.h
+++ b/include/f_op/f_op_actor_mng.h
@@ -842,7 +842,7 @@ void fopAcM_showAssert_f(const fopAc_ac_c*, const char*, int, const char*, ...);
#define fopAcM_setWarningMessage(...)
#endif
-void fopAcM_getNameString(const fopAc_ac_c*, char*);
+BOOL fopAcM_getNameString(const fopAc_ac_c*, char*);
class fopAcM_lc_c {
public:
diff --git a/include/f_op/f_op_scene.h b/include/f_op/f_op_scene.h
index 2da8e5e9ba..a42eee7211 100644
--- a/include/f_op/f_op_scene.h
+++ b/include/f_op/f_op_scene.h
@@ -2,20 +2,25 @@
#define F_F_OP_SCENE_H_
#include "f_op/f_op_scene_tag.h"
+#include "f_pc/f_pc_leaf.h"
struct request_of_phase_process_class;
class mDoDvdThd_command_c;
+struct scene_method_class {
+ /* 0x00 */ leafdraw_method_class base;
+};
+
typedef struct scene_process_profile_definition {
/* 0x00 */ node_process_profile_definition nase;
/* 0x20 */ process_method_class* submethod; // Subclass methods
/* 0x24 */ u32 unk_0x24; // padding?
} scene_process_profile_definition;
class scene_class {
public:
/* 0x000 */ process_node_class base;
- /* 0x1AC */ process_method_class* submethod;
+ /* 0x1AC */ scene_method_class* submethod;
/* 0x1B0 */ scene_tag_class scene_tag;
};
@@ -2,20 +2,25 @@
typedef struct scene_process_profile_definition {
/* 0x00 */ node_process_profile_definition nase;
- /* 0x20 */ process_method_class* submethod; // Subclass methods
+ /* 0x20 */ scene_method_class* submethod; // Subclass methods
/* 0x24 */ u32 unk_0x24; // padding?
} scene_process_profile_definition;